package com.jz.dmp.modules.service.impl;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.agent.service.DmpDsAgentService;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.BasePageBean;
import com.jz.common.page.PageInfoResponse;
import com.jz.common.persistence.BaseService;
import com.jz.common.utils.AzkabanApiUtils2;
import com.jz.common.utils.FileUtils;
import com.jz.common.utils.JsonMapper;
import com.jz.common.utils.ZipUtils;
import com.jz.common.utils.web.XmlUtils;
import com.jz.dmp.agent.DmpAgentResult;
import com.jz.dmp.modules.controller.DataIntegration.bean.*;
import com.jz.dmp.modules.controller.DataIntegration.bean.flow.FlowExecution;
import com.jz.dmp.modules.dao.*;
import com.jz.dmp.modules.model.*;
import com.jz.dmp.modules.service.DmpDevelopTaskService;
import com.jz.dmp.modules.service.DvTaskRuleTService;
import com.jz.dmp.modules.service.OfflineSynchService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @Description:离线同步服务层
 * @ClassName: OfflineSynchServiceImpl
 * @Author Bellamy
 * @Date 2020/12/20
 */

@Service("offlineSynchService")
@Transactional
public class OfflineSynchServiceImpl implements OfflineSynchService {

    private static Logger logger = LoggerFactory.getLogger(OfflineSynchServiceImpl.class);

    @Value("${spring.public-key}")
    private String publicKey;

    @Autowired
    private OfflineSynchDao offlineSynchDao;

    @Autowired
    private DmpProjectDao dmpProjectDao;

    @Autowired
    private DmpDevelopTaskDao dmpDevelopTaskDao;

    @Autowired
    private DmpDsAgentService dmpDsAgentServiceImp;

    @Autowired
    private DmpTableDao dmpTableDao;

    @Autowired
    private DmpTableFieldSchemaDao dmpTableFieldSchemaDao;

    @Autowired
    private DmpTableColumnDao dmpTableColumnDao;

    @Autowired
    private DvRuleTDao dvRuleTDao;

    @Autowired
    private DmpNavigationTreeDao dmpNavigationTreeDao;

    @Autowired
    private DmpDevelopTaskService dmpDevelopTaskService;

    @Autowired
    private DvTaskRuleTService dvTaskRuleTService;

    @Override
    public PageInfoResponse<TaskListPageDto> queryTaskListPage(TaskListPageReq taskListPageReq) throws Exception {
        PageInfoResponse<TaskListPageDto> pageInfoResponse = new PageInfoResponse<>();

        PageHelper.startPage(taskListPageReq.getPageNum(), taskListPageReq.getPageSize());
        List<TaskListPageDto> list = offlineSynchDao.selectOfflineTaskInfo(taskListPageReq);
        PageInfo<TaskListPageDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(ResultCode.SUCCESS);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /**
     * 获取源数据库名称——下拉框
     */
    @Override
    public JsonResult<List<SourceDbNameListDto>> querygSourceDbList(Integer projectId) throws Exception {
        Map map = new HashMap();
        map.put("projectId", projectId); //项目id
        map.put("isEnableSource", "1");
        List<SourceDbNameListDto> list = offlineSynchDao.querygSourceDbList(map);
        return new JsonResult(ResultCode.SUCCESS, list);
    }

    /**
     * 根据源数据库id,获取源数据表——下拉框
     */
    @Override
    public JsonResult querygSourceTableList(Long sourceDbId, String targetName) throws Exception {
        //通过源数据库id ，查询数据源配置
        DmpAgentDatasourceInfo dsInfo = offlineSynchDao.querySourceDbInfoBySourceId(sourceDbId);
        //解码源数据库密码
        if (StringUtils.isNotBlank(dsInfo.getPassword())) {
            dsInfo.setPassword(new BaseService().decode(dsInfo.getPassword(), publicKey));
        }
        if (StringUtils.isNotBlank(targetName)) {
            dsInfo.setTargetFileName(targetName);
        }
        //创建jdbc,获取源数据表
        DmpAgentResult rst = dmpDsAgentServiceImp.getTableNameList(dsInfo);
        if (!rst.getCode().val().equals("200")) {
            return new JsonResult(rst.getCode(), rst.getMessage());
        } else {
            //成功
            rst.setResult(JsonMapper.fromJsonString(rst.getMessage(), List.class));
            return new JsonResult(ResultCode.SUCCESS, rst);
        }
    }

    /**
     * 立即运行
     */
    @Override
    public JsonResult taskRunNowByTaskId(String taskId) throws Exception {
        boolean flag = false;
        //根据任务id，查询DMP资源导航树和DW系统配置信息
        Map<String, Object> map = offlineSynchDao.selectNavigationTreeByTaskId(taskId);
        if (map.size() > 0 && map != null) {
            flag = this.publish(map);
            if (flag) {
                return new JsonResult(ResultCode.SUCCESS, flag);
            } else {
                return new JsonResult(ResultCode.SYS_ERROR, flag);
            }
        } else {
            return new JsonResult(ResultCode.SYS_ERROR, flag);
        }
    }

    /**
     * 发布流程
     */
    private boolean publish(Map<String, Object> map) {
        String taskId = map.get("taskId").toString(); //任务id
        String projectId = map.get("projectId").toString(); //项目id
        String treeName = map.get("treeName").toString(); //流程名称
        String azkabanExectorXmlExec = map.get("azkabanExectorXmlExec").toString(); //执行数据同步任务命令
        String azkabanLocalTaskFilePath = map.get("azkabanLocalTaskFilePath").toString(); //文件路径
        String azkabanMonitorUrl = map.get("azkabanMonitorUrl").toString();//AZKABAN WEB服务地址

        String azkabanJobCommand = "command=" + azkabanExectorXmlExec + " " + projectId + " ${azkaban.flow.flowid} ${azkaban.job.id} ${azkaban.flow.execid} " + treeName;

        /**
         * 当前任务生成文件存放根路径
         */
        String localTaskPath = azkabanLocalTaskFilePath + "/" + projectId + "/local/" + taskId;
        File localTaskFile = new File(localTaskPath);
        if (!localTaskFile.exists()) {
            localTaskFile.mkdirs();
        }

        String localTaskSourcePath = localTaskPath + "/source/";
        File localTaskSourceFile = new File(localTaskSourcePath);
        if (!localTaskSourceFile.exists()) {
            localTaskSourceFile.mkdirs();
        }

        String localTaskExecArgsPath = localTaskPath + "/execArgs/";
        File localTaskExecArgsFile = new File(localTaskExecArgsPath);
        if (!localTaskExecArgsFile.exists()) {
            localTaskExecArgsFile.mkdirs();
        }

        String localTaskZipPath = localTaskPath + "/target/";
        File localTaskZipFile = new File(localTaskZipPath);
        if (!localTaskZipFile.exists()) {
            localTaskZipFile.mkdirs();
        }

        //先删除上次创建的文件 ---每次都会新建
        FileUtils.deleteDirectory(localTaskPath);


        List<String> contents = new ArrayList<>();

        // 子流程类型
        contents.add("type=command");
        contents.add(azkabanJobCommand);

        // 生成job文件
        String jobFileAbsolutePath = localTaskSourcePath + treeName + ".job";
        FileUtils.write(jobFileAbsolutePath, contents);

        String localZipTargetFileName = treeName + ".zip";
        ZipUtils.zip(localTaskSourcePath, localTaskZipPath, localZipTargetFileName);

        //上传到azkaban todo
        //上次zip包到azkaban
        String localTaskZipAbsolutePath = localTaskZipPath + "/" + localZipTargetFileName;
        AzkabanApiUtils2 azkabanApiUtils = new AzkabanApiUtils2(azkabanMonitorUrl);
        return azkabanApiUtils.loginCreateProjectuploadZipAndExecute("jz_localflow_" + projectId, "local_sync_project", localTaskZipAbsolutePath, treeName);
    }

    /**
     * 删除任务
     */
    @Override
    public JsonResult delTaskByTaskId(String taskId) throws Exception {
        //通过taskId，查询任务和资源是否存在
        Map map = dmpDevelopTaskDao.getDmpTaskAndTreeInfo(taskId);
        if (map.size() == 0 || map == null) {
            return new JsonResult(ResultCode.OPERATION_DATA_NO_EXIST);
        }
        if (StringUtils.isEmpty(map.get("treeId").toString())) {
            return new JsonResult(ResultCode.OPERATION_DATA_NO_EXIST);
        }
        dmpDevelopTaskDao.deleteTaskByTaskId(taskId);
        dmpDevelopTaskDao.deleteNavigationTreeByTreeId(map.get("treeId").toString());
        return new JsonResult(ResultCode.SUCCESS);
    }

    /**
     * 任务状态查看，异步调用azkaban服务
     */
    @Override
    public JsonResult<List<CheckTaskStatusPageDto>> queryCheckTaskStatusListPage(CheckTaskStatusPageReq checkTaskStatusPageReq) throws Exception {
        List<FlowExecution> list = new ArrayList<>();

        Long projectId = Long.valueOf(checkTaskStatusPageReq.getProjectId()); //项目id
        String treeName = checkTaskStatusPageReq.getTreeName(); //任务树名称
        DmpProjectSystemInfo publishToProjectSystemInfo = dmpProjectDao.queryProjectSystemInfo(projectId);

        //调用azkaban服务
        String azkabanApiUrl = publishToProjectSystemInfo.getAzkabanMonitorUrl();
        AzkabanApiUtils2 azkabanApiUtils = new AzkabanApiUtils2(azkabanApiUrl);
        list = azkabanApiUtils.getSyncingFlowExecution(projectId, treeName, checkTaskStatusPageReq.getPageNum(), checkTaskStatusPageReq.getPageSize());

        SimpleDateFormat dtf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<CheckTaskStatusPageDto> returnList = new ArrayList<>();
        if (list.size() > 0 && list != null) {
            for (FlowExecution str : list) {
                CheckTaskStatusPageDto dto = new CheckTaskStatusPageDto();
                long endTime = str.getEndTime();
                long startTime = str.getStartTime();
                dto.setCostTime(endTime - startTime); //耗时
                dto.setExecId(str.getExecId()); //任务执行id
                dto.setStatus(str.getStatus());
                dto.setSubmitUser(str.getSubmitUser());
                dto.setEndTime(dtf.format(new Date(endTime))); //结束时间
                dto.setStartTime(dtf.format(new Date(startTime))); //开始时间
                returnList.add(dto);
            }
        }
        return new JsonResult(ResultCode.SUCCESS, returnList);
    }

    @Override
    public PageInfoResponse<CheckJyRlueStatusDto> selectCheckJyStatusInfo(CheckJyRlueStatusReq checkJyRlueStatusReq) throws Exception {
        PageInfoResponse<CheckJyRlueStatusDto> pageInfoResponse = new PageInfoResponse<>();

        PageHelper.startPage(checkJyRlueStatusReq.getPageNum(), checkJyRlueStatusReq.getPageSize());
        List<CheckJyRlueStatusDto> list = offlineSynchDao.selectCheckJyStatusInfo(checkJyRlueStatusReq.getExecutionId());
        PageInfo<CheckJyRlueStatusDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(ResultCode.SUCCESS);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    @Override
    public JsonResult querySoureAndTargetColumnsByParams(SoureAndTargetColumnsReq soureAndTargetColumnsReq) throws Exception {
        //通过源数据库id ，查询数据源配置
        DmpAgentDatasourceInfo dsInfo = offlineSynchDao.querySourceDbInfoBySourceId(soureAndTargetColumnsReq.getSourceDbId());

        //通过目标数据库id ，查询数据配置
        DmpAgentDatasourceInfo targetInfo = offlineSynchDao.querySourceDbInfoBySourceId(soureAndTargetColumnsReq.getTargetDbId());

        //dsInfo.setHdfsUserName(body.getAccessId()); // 专为HDFS CLIENT提供
        dsInfo.setFileType(soureAndTargetColumnsReq.getFileType());
        dsInfo.setDelimiter(soureAndTargetColumnsReq.getCsvDelimiter());
        dsInfo.setIsHaveHeader(soureAndTargetColumnsReq.getCsvIsHaveHeader());

        //解码源数据库密码
        if (StringUtils.isNotBlank(dsInfo.getPassword())) {
            dsInfo.setPassword(new BaseService().decode(dsInfo.getPassword(), publicKey));
        }

        //创建jdbc,获取源数据表字段
        DmpAgentResult rst = dmpDsAgentServiceImp.getTableColumnList(dsInfo, soureAndTargetColumnsReq.getTargetTableName());
        if (!rst.getCode().val().equals("200")) {
            return new JsonResult(rst.getCode(), rst.getMessage());
        }
        List<Map<String, Object>> cols = (List<Map<String, Object>>) JsonMapper.fromJsonString(rst.getMessage(), List.class);
        if (cols == null || cols.size() == 0) {
            return new JsonResult(ResultCode.INTERNAL_SERVER_ERROR, "获取不到对应数据源的数据");
        }
        logger.info("######################################  数据源的表字段 success  ####################################");

        DmpTable table = new DmpTable(); //项目表信息
        table.setTableMode(dsInfo.getDatasourceTypeId()); //数据源类型ID
        table.setCnName(soureAndTargetColumnsReq.getTargetTableName()); //中文名
        table.setIsShow("0"); //是否隐藏
        table.setName(soureAndTargetColumnsReq.getTargetTableName());//表名
        table.setTableDesc("数据同步-源表"); //描述
        table.setDataStatus("1"); //数据表状态 默认1

        dmpTableDao.deleteTableColumnByName(table);
        dmpTableDao.deleteTableByName(table);
        dmpTableDao.insert(table);

        DmpTableFieldSchema schema = new DmpTableFieldSchema(); //项目表字段类型
        schema.setDsId(Integer.valueOf(dsInfo.getDatasourceTypeId()));
        List<DmpTableFieldSchema> sourceFieldSchema = dmpTableFieldSchemaDao.queryAll(schema); //源字段架构
        schema.setDsId(Integer.valueOf(dsInfo.getDatasourceTypeId()));
        List<DmpTableFieldSchema> targetFieldSchema = dmpTableFieldSchemaDao.queryAll(schema); //目标字段架构
        if (sourceFieldSchema != null && sourceFieldSchema.size() > 0) {
            Map<String, Integer> ftm = new HashMap<String, Integer>();
            for (DmpTableFieldSchema s : sourceFieldSchema) { //便利源字段类型
                ftm.put(s.getFieldType(), s.getId().intValue());
            }
            List<DmpTableColumn> columns = new ArrayList<DmpTableColumn>();
            for (int i = 0; i < cols.size(); i++) { //便利源字段
                Map<String, Object> map = cols.get(i);
                String name = (String) map.get("name");
                String type = (String) map.get("type");
                Integer size = (Integer) map.get("size");
                Integer scale = (Integer) map.get("scale");
                String comment = (String) map.get("comment");

                DmpTableColumn dtc = new DmpTableColumn();
                dtc.setField(name); //字段
                dtc.setType(ftm.get(type)); //类型
                if (size != null) dtc.setSize(size); //大小
                if (scale != null) dtc.setScale(scale); //经度
                dtc.setTableId(table.getId().intValue()); //tableID
                dtc.setComment(comment); //备注说明
                dtc.setDataStatus("1"); //数据表状态 默认1
                columns.add(dtc);
            }
            //向dmp_table_column批量新增
            dmpTableColumnDao.insertBatch(columns);
        }

        Map<String, Object> params = new HashMap<String, Object>();
        params.put("targetDsId", targetInfo.getDatasourceTypeId()); //数据源类型ID
        params.put("sourceDsId", dsInfo.getDatasourceTypeId());
        params.put("tableName", soureAndTargetColumnsReq.getTargetTableName());
        List<Map<String, Object>> fieldsMappingList = dmpTableFieldSchemaDao.getTableFieldsMapping(params);
        List<Map<String, Object>> sourceFieldColumns = new ArrayList<Map<String, Object>>();
        List<Map<String, Object>> targetFieldColumns = new ArrayList<Map<String, Object>>();
        for (Map<String, Object> m : fieldsMappingList) {
            String field = (String) m.get("field");
            String sourceType = (String) m.get("sourceType");
            String targetType = "STRING";
            if (m.get("targetType") != null && StringUtils.isNotBlank((String) m.get("targetType"))) {
                targetType = (String) m.get("targetType");
            }
            Integer size = (Integer) m.get("size");
            Integer scale = (Integer) m.get("scale");

            Map<String, Object> sourceFieldColumn = new HashMap<String, Object>();//源表字段
            sourceFieldColumn.put("name", field); //字段
            sourceFieldColumn.put("type", sourceType); //类型
            sourceFieldColumn.put("size", size); //大小
            sourceFieldColumn.put("scale", scale); //经度

            Map<String, Object> targetFieldColumn = new HashMap<String, Object>();//目标表字段
            targetFieldColumn.put("name", field);
            targetFieldColumn.put("type", targetType);
            targetFieldColumn.put("size", size);
            targetFieldColumn.put("scale", scale);

            sourceFieldColumns.add(sourceFieldColumn);
            targetFieldColumns.add(targetFieldColumn);
        }
        Map<String, Object> bak = new HashMap<String, Object>();
        //bak.put("sourceFieldSchema", sourceFieldSchema);
        bak.put("sourceFieldColumns", sourceFieldColumns);
        //bak.put("targetFieldSchema", targetFieldSchema);
        bak.put("targetFieldColumns", targetFieldColumns);

        dmpTableDao.deleteById(table.getId());
        dmpTableColumnDao.deleteByTableId(table.getId());
        return new JsonResult(ResultCode.SUCCESS, bak);
    }

    @Override
    public PageInfoResponse<DvRuleTDto> queryJyRuleListPage(BasePageBean basePageBean, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<DvRuleTDto> pageInfoResponse = new PageInfoResponse<>();

        PageHelper.startPage(basePageBean.getPageNum(), basePageBean.getPageSize());
        DvRuleT dvRuleT = new DvRuleT();
        List<DvRuleTDto> list = dvRuleTDao.queryJyRuleListPage(dvRuleT);
        if (list.size() > 0 && list != null) {
            for (DvRuleTDto dto : list) {
                dto.setRuleContentJson(JSON.parseObject(dto.getRuleContent()));
            }
        }
        PageInfo<DvRuleTDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(ResultCode.SUCCESS);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /**
     * 添加保存dmp数据(包含校验数据)
     *
     * @param syncDmpTaskAddReq
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRES_NEW)
    public JsonResult addSyncTask(SyncDmpTaskAddReq syncDmpTaskAddReq) throws Exception {
        List<Map<String, Object>> result = new ArrayList<>();
        Map<String, Object> reqParam = syncDmpTaskAddReq.getParams();
        if (reqParam.size() > 0 && reqParam != null) {
            JsonResult jsonResult = addSyncing(reqParam);
            DmpDevelopTask data = (DmpDevelopTask) jsonResult.getData();
            saveRuleInfo(result, reqParam, jsonResult, String.valueOf(data.getId()));
        }
        return new JsonResult(ResultCode.SUCCESS, result);
    }

    /**
     * 添加保存离线任务dmp数据
     *
     * @param body
     * @return
     */
    public JsonResult addSyncing(Map<String, Object> body) throws  Exception {
        Integer projectId = (Integer) body.get("projectId");
        Integer parentId = (Integer) body.get("parentId"); //父节点ID
        String taskName = (String) body.get("taskName"); //任务名称 业务节点名称 一对一
        Integer treeId = (Integer) body.get("treeId"); //树节点ID

        if (StringUtils.isBlank(taskName)) {
            return new JsonResult(ResultCode.PARAMS_ERROR, "任务名称不能为空");
        }
        Map<String, Object> scriptMap = (Map<String, Object>) body.get("scripts"); //任务json数据
        Object content = scriptMap.get("content");
        String xmlTdb = XmlUtils.getPropertyValue(content, "target_db_connection");
        if (null != content && xmlTdb.length() == 0) { // 包含content但未取出值条件才成立
            return new JsonResult(ResultCode.PARAMS_ERROR, "脚本内容中缺失目标数据源(target_db_connection)");
        }

        /*DmpNavigationTree tree = new DmpNavigationTree();
        tree.setName(taskName); //树节点名称
        tree.setProjectId(projectId);
        tree.setCategory("2"); //树类别
        tree.setIsLevel("1"); //是否叶子节点 1 是
        int cnt = dmpNavigationTreeDao.countTreeByName(tree);
        if (cnt > 0) {
            throw new RuntimeException("当前项目已存在同名的任务");
        }*/

        //保存目标库类型
        Integer dataSourceId = null; //数据源ID
        Map<String, Object> writer = (Map<String, Object>) scriptMap.get("writer");  // 目标数据
        String targetDb = (String) writer.get("targetDbConnection"); // 目标库名称
        String targetTable = (String) writer.get("targetTable"); // 目标库表名称

        Map<String, Object> reader = (Map<String, Object>) scriptMap.get("reader");//源数据
        String sourceDbName = (String) reader.get("dbConnection"); // 源库名称
        String sourceTableName = (String) reader.get("registerTableName"); // 源库表名称

        if (StringUtils.isNotBlank(targetDb)) {
            //根据 目标库和项目id 查询
            dataSourceId = dmpDevelopTaskDao.getDbInfoByParam(targetDb, projectId);
        }

        DmpDevelopTask task = new DmpDevelopTask();
        task.setProjectId(projectId);
        task.setParentId(parentId);
        task.setTaskType("2"); //任务类型
        task.setDatasourceId(dataSourceId); //数据源ID
        task.setType("3");
        //task.setTaskName(taskName);
        task.setTaskDesc("Syncing Task"); //任务描述
        task.setIsSubmit("0"); //是否已提交
        task.setTreeId(treeId);
        String script = JsonMapper.toJsonString(body);
        byte[] data = null;
        try {
            data = script.getBytes("utf-8");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        task.setData(data); //json 数据
        task.setTargetDbName(targetDb);
        task.setTargetTableName(targetTable);
        task.setSourceTableName(sourceTableName);
        task.setSourceDbName(sourceDbName);
        dmpDevelopTaskDao.insert(task); //保存任务数据

        //保存时提交XML
        /*DmpTaskSchedule schedule = new DmpTaskSchedule();
        schedule.setTreeId(task.getTreeId());
        schedule.setProjectId(projectId);*/
        dmpDevelopTaskService.submitSyncing(task);

        return new JsonResult(ResultCode.SUCCESS, task);
    }

    /**
     * 保存规则信息
     *
     * @param result
     * @param reqParam
     * @param jsonResult
     * @param taskId
     * @throws Exception
     */
    private void saveRuleInfo(List<Map<String, Object>> result, Map<String, Object> reqParam, JsonResult jsonResult, String taskId) throws Exception {
        List<DvTaskRuleT> list = new ArrayList<>();
        if (jsonResult.getCode().equals(ResultCode.SUCCESS.val())) {
            List<Map> rules = (List<Map>) reqParam.get("taskRules"); //规则信息
            if (!CollectionUtils.isEmpty(rules)) {
                settRuleInfo(taskId, rules, list);
            }
        } else {
            HashMap<String, Object> errorMap = new HashMap<>();
            errorMap.put("name", reqParam.get("name"));
            errorMap.put("msg", jsonResult.getMessage());
            errorMap.put("code", jsonResult.getCode());
            result.add(errorMap);
        }
    }

    /**
     * 保存dmp数据校验信息
     *
     * @param taskId
     * @param rules
     * @param list
     * @throws Exception
     */
    private void settRuleInfo(String  taskId, List<Map> rules, List<DvTaskRuleT> list) throws Exception {
        for (Map rule : rules) {
            DvTaskRuleT taskRuleT = new DvTaskRuleT();
            Integer ruleId = (Integer) rule.get("ruleId");
            String ruleValue = (String) rule.get("ruleValue");
            taskRuleT.setTaskId(taskId);//任务ID
            taskRuleT.setRuleId(ruleId.longValue());
            taskRuleT.setRuleValue(ruleValue);
            list.add(taskRuleT);
        }
        //批量新增任务与规则关系表
        dvTaskRuleTService.saveRule(list);
    }
}
